@@ -7,7 +7,7 @@ use LWP;
 use JSON;
 use String::Random;
 
-our $VERSION = "1.06";
+our $VERSION = "1.07";
 
 has 'server' => (
     is       => 'rw',
@@ -259,9 +259,9 @@ running scripts.
 
 =head1 DESCRIPTION
 
-This module functions as a simple wrapper to eliminate boilerplate that might otherwise need to be created when interfacing with the Zabbix API.  Login to the Zabbix server is handled with the constructor. Beyond that, the primary method is the C<do> method. The user.logout method is implemented  in the object deconstructor as well, so there should be no need to explicity logout of Zabbix.
+This module functions as a simple wrapper to eliminate boilerplate that might otherwise need to be created when interfacing with the Zabbix API.  Login to the Zabbix server is handled with the constructor. Beyond that, the primary method is the C<do> method. The user.logout method is implemented  in the object deconstructor as well, so there should be no need to explicitly logout of Zabbix.
 
-This module was developed against Zabbix 2.4, and is expected to work with Zabbix 2.2, and likely 2.0 as well.  It is much less certain it will work with Zabbix 1.8.  Please refer to the API section of the Zabbix manual for details on its methods.
+This module is currently developed against Zabbix 3.0.  It is expected to work with Zabbix 2.4, 2.2, and likely 2.0 as well.  It is much less certain it will work with Zabbix 1.8.  Please refer to the API section of the Zabbix manual for details on its methods.
 
 =head1 METHODS
 
@@ -273,13 +273,19 @@ This module was developed against Zabbix 2.4, and is expected to work with Zabbi
 
 The constructor requires server, user, and password.  It will create the Zabbix::Tiny object, and log in to the server all at once.  The C<ssl_opts> argument can be set to set the LWP::UserAgent ssl_opts attribute when connecting to https with a self-signed or otherwise un-trusted certificate (see note about untrusted certificates below).
 
+=item $zabbix->prepare('zabbix.method', $params );
+
+This creates the json string to be sent to the Zabbix server.  It can then be executed with the C<execute> method.
+
 =item my $hosts = $zabbix->do('zabbix.method', ... );
 
+ my $hosts = $zabbix->do;
  my $hosts = $zabbix->do('zabbix.method', {%params});
  my $hosts = $zabbix->do('zabbix.method', [@params]);
  my $hosts = $zabbix->do('zabbix.method', %params); ## Depricated
 
-This will execute any defined Zabbix method, with the corresponding params.  Refer to the Zabbix manual for a list of available methods.  If the Zabbix method is of a *.get flavor, the return is an arrayref data structure containing the response from the Zabbix server.  Starting with v1.05, it is preferred to pass parameters as a hashref or an arrayref, since a few Zabbix API methods take an array, rather than a hash of parameters.  Support for params as a hash are still supported for backwards compatibility.
+This will execute any defined Zabbix method, with the corresponding params.  Refer to the Zabbix manual for a list of available methods.  If the Zabbix method is of a *.get flavor, the return is an arrayref data structure containing the response from the Zabbix server.  Starting with v1.05, it is preferred to pass parameters as a hashref or an arrayref, since a few Zabbix API methods take an array, rather than a hash of parameters.  Support for params as a hash are still supported for backwards compatibility.  Calling C<do> without any arguments will use the currently prepared json string.  It also calls C<prepare> immediately after executing. This not only allows for a statement to be prepared, then examined, then executed for debugging purposes.  It also allows for the same query to be run multiple times in a row.
+
 
 =back
 
@@ -339,7 +345,7 @@ In many cases it is expected that zabbix servers may be using self-signed or oth
 
 =head1 See Also
 
-Zabbix API Documentation: L<https://www.zabbix.com/documentation/2.4/manual/api>
+Zabbix API Documentation: L<https://www.zabbix.com/documentation/3.0/manual/api>
 
 =head1 COPYRIGHT
 
